@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 from debmutate.control import ControlEditor
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+from lintian_brush.fixer import report_result, LintianIssue
 
 removed = []
 
@@ -11,11 +11,12 @@ with ControlEditor() as updater:
             if updater.source.get(field) == value:
                 del binary[field]
                 removed.append((binary['Package'], field, value))
-                fixed_lintian_tag(
+                issue = LintianIssue(
                     updater.source,
                     'binary-control-field-duplicates-source',
                     info='field "%s" in package %s' % (
                         field, binary['Package']))
+                issue.report_fixed()
 
 
 report_result(
