@@ -17,10 +17,27 @@
 
 """Handling of quilt patches."""
 
+__all__ = [
+    'PatchSyntax',
+    'find_patch_base',
+    'find_patches_branch',
+    'AppliedPatches',
+    'read_quilt_patches',
+    'PatchApplicationBaseNotFound',
+    'upstream_with_applied_patches',
+    'find_patches_directory',
+    'rules_find_patches_directory',
+    'tree_patches_directory',
+    'add_patch',
+    'move_upstream_changes_to_patch',
+    ]
+
 import contextlib
+from datetime import datetime
 from email.message import Message
 from io import BytesIO
 import os
+from typing import Optional, Tuple, List
 
 from breezy.diff import show_diff_trees
 from breezy import osutils
@@ -28,13 +45,25 @@ from breezy.commit import filter_excluded
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
 from breezy.errors import NotBranchError, NoSuchFile
-from breezy.patches import parse_patches, apply_patches
+from breezy.patches import (
+    parse_patches,
+    apply_patches,
+    PatchSyntax,
+    )
+from breezy.tree import Tree
+from breezy.workingtree import WorkingTree
 
 from debian.changelog import Changelog
 
+from debmutate.patch import (
+    QuiltSeriesEditor,
+    read_quilt_series,
+    find_common_patch_suffix,
+    )
+
 from . import reset_tree
 
-
+# TODO(jelmer): Use debmutate version
 DEFAULT_DEBIAN_PATCHES_DIR = 'debian/patches'
 
 
@@ -116,24 +145,6 @@ class AppliedPatches(object):
         return False
 
 
-# TODO(jelmer): Use debmutate version
-def read_quilt_series(f):
-    for line in f:
-        if line.startswith(b'#'):
-            quoted = True
-            line = line.split(b'#')[1].strip()
-        else:
-            quoted = False
-        args = line.decode().split()
-        if not args:
-            continue
-        patch = args[0]
-        if not patch:
-            continue
-        options = args[1:]
-        yield patch, quoted, options
-
-
 def read_quilt_patches(tree, directory=DEFAULT_DEBIAN_PATCHES_DIR):
     """Read patch contents from quilt directory.
 
@@ -148,11 +159,11 @@ def read_quilt_patches(tree, directory=DEFAULT_DEBIAN_PATCHES_DIR):
         series_lines = tree.get_file_lines(series_path)
     except NoSuchFile:
         return []
-    for patchname, quoted, options in read_quilt_series(series_lines):
-        if quoted:
+    for entry in read_quilt_series(series_lines):
+        if entry.quoted:
             continue
         # TODO(jelmer): Pass on options?
-        with tree.get_file(osutils.pathjoin(directory, patchname)) as f:
+        with tree.get_file(osutils.pathjoin(directory, entry.name)) as f:
             for patch in parse_patches(f, allow_dirty=True, keep_dirty=False):
                 yield patch
 
@@ -223,7 +234,7 @@ def find_patches_directory(path):
     return directory
 
 
-def tree_patches_directory(tree):
+def tree_patches_directory(tree, subpath=''):
     """Find the name of the patches directory.
 
     This will always return a path, even if the patches
@@ -234,7 +245,7 @@ def tree_patches_directory(tree):
     Returns:
       path to patches directory, or what it should be
     """
-    directory = find_patches_directory(tree.abspath('.'))
+    directory = find_patches_directory(tree.abspath(subpath))
     if directory is None:
         return DEFAULT_DEBIAN_PATCHES_DIR
     return directory
@@ -266,31 +277,6 @@ def tree_non_patches_changes(tree, patches_directory):
             yield change
 
 
-# TODO(jelmer): Use debmutate version
-def find_common_patch_suffix(names, default='.patch'):
-    """Find the common prefix to use for patches.
-
-    Args:
-      names: List of filenames in debian/patches/
-      default: Default suffix if no default can be found
-    Returns:
-      a suffix
-    """
-    suffix_count = {}
-    for name in names:
-        if name in ('series', '00list'):
-            continue
-        if name.startswith('README'):
-            continue
-        suffix = os.path.splitext(name)[1]
-        if suffix not in suffix_count:
-            suffix_count[suffix] = 0
-        suffix_count[suffix] += 1
-    if not suffix_count:
-        return default
-    return max(suffix_count.items(), key=lambda v: v[1])[0]
-
-
 def add_patch(tree, patches_directory, name, contents, header=None):
     """Add a new patch.
 
@@ -304,31 +290,35 @@ def add_patch(tree, patches_directory, name, contents, header=None):
       Name of the patch that was written (including suffix)
     """
     if not tree.has_filename(patches_directory):
+        if not tree.has_filename(os.path.dirname(patches_directory)):
+            tree.mkdir(os.path.dirname(patches_directory))
         tree.mkdir(patches_directory)
-    patch_suffix = find_common_patch_suffix(os.listdir(patches_directory))
+    abs_patches_dir = tree.abspath(patches_directory)
+    patch_suffix = find_common_patch_suffix(os.listdir(abs_patches_dir))
     patchname = name + patch_suffix
-    path = os.path.join(patches_directory, patchname)
+    path = os.path.join(abs_patches_dir, patchname)
     if tree.has_filename(path):
         raise FileExistsError(path)
     with open(tree.abspath(path), 'wb') as f:
         if header is not None:
             f.write(header.as_string().encode('utf-8'))
-            f.write(b'\n')
         f.write(contents)
 
     # TODO(jelmer): Write to patches branch if applicable
 
-    # TODO(jelmer): Use debmutate SeriesEditor
-    series_path = os.path.join(patches_directory, 'series')
-    with open(tree.abspath(series_path, 'a')) as f:
-        f.write('%s\n' % patchname)
+    series_path = os.path.join(abs_patches_dir, 'series')
+    with QuiltSeriesEditor(series_path) as editor:
+        editor.append(patchname)
 
     return patchname
 
 
 def move_upstream_changes_to_patch(
-        local_tree, subpath, patch_name, description,
-        dirty_tracker=None):
+        local_tree: WorkingTree,
+        basis_tree: Tree,
+        subpath: str, patch_name: str, description: str,
+        dirty_tracker=None,
+        timestamp: Optional[datetime] = None) -> Tuple[List[str], str]:
     """Move upstream changes to patch.
 
     Args:
@@ -338,17 +328,22 @@ def move_upstream_changes_to_patch(
       description: Description
       dirty_tracker: Dirty tracker
     """
+    if timestamp is None:
+        timestamp = datetime.now()
     diff = BytesIO()
-    basis_tree = local_tree.basis_tree()
     show_diff_trees(basis_tree, local_tree, diff)
-    reset_tree(local_tree, dirty_tracker, subpath)
+    reset_tree(local_tree, basis_tree, subpath, dirty_tracker)
     header = Message()
     lines = description.splitlines()
-    header['Description'] = lines[0].rstrip('\n')
-    header.set_payload(''.join([line + '\n' for line in lines[1:]]).lstrip())
-    patches_directory = tree_patches_directory(local_tree)
+    # See https://dep-team.pages.debian.net/deps/dep3/ for fields.
+    header['Description'] = lines[0] + '\n' + '\n'.join(
+            [(' ' + line) if line else ' .' for line in lines[1:]])
+    header['Origin'] = 'other'
+    header['Last-Update'] = timestamp.strftime('%Y-%m-%d')
+    patches_directory = tree_patches_directory(local_tree, subpath)
     patchname = add_patch(
-        local_tree, patches_directory, patch_name, diff.getvalue(), header)
+        local_tree, os.path.join(subpath, patches_directory),
+        patch_name, diff.getvalue(), header)
     specific_files = [
         os.path.join(subpath, patches_directory),
         os.path.join(subpath, patches_directory, 'series'),
