@@ -17,17 +17,16 @@
 
 """Tests for lintian_brush.lintian_overrides."""
 
+import os
+
 from breezy.tests import (
-    TestCase,
     TestCaseWithTransport,
     )
 
 from lintian_brush.lintian_overrides import (
-    Override,
+    LintianOverride,
     overrides_paths,
     override_exists,
-    parse_override,
-    serialize_override,
     update_overrides_file,
     _get_overrides,
     )
@@ -61,6 +60,33 @@ foo [any-i386] binary: another-tag optional-extra
         self.assertFalse(update_overrides_file(cb=cb, path='overrides'))
         self.assertFileEqual(CONTENT, 'overrides')
 
+    def test_delete_last(self):
+        CONTENT = """\
+# An architecture wildcard would look like:
+foo [any-i386] binary: another-tag optional-extra
+"""
+        self.build_tree_contents([('overrides', CONTENT)])
+
+        def cb(override):
+            return None
+
+        self.assertTrue(update_overrides_file(cb=cb, path='overrides'))
+        self.assertFalse(os.path.exists('overrides'))
+
+    def test_delete(self):
+        CONTENT = """\
+# An architecture wildcard would look like:
+foo [any-i386] binary: another-tag optional-extra
+bar binary: onetag
+"""
+        self.build_tree_contents([('overrides', CONTENT)])
+
+        def cb(override):
+            return override if override.tag != 'another-tag' else None
+
+        self.assertTrue(update_overrides_file(cb=cb, path='overrides'))
+        self.assertFileEqual('bar binary: onetag\n', 'overrides')
+
     def test_change_set_archlist(self):
         self.build_tree_contents([('overrides', """\
 # An architecture wildcard would look like:
@@ -68,10 +94,10 @@ foo binary: another-tag optional-extra
 """)])
 
         def cb(override):
-            return Override(
+            return LintianOverride(
                 tag=override.tag, package=override.package,
                 type=override.type, info=override.info,
-                archlist='any-i386')
+                archlist=['any-i386'])
 
         self.assertTrue(update_overrides_file(cb=cb, path='overrides'))
         self.assertFileEqual("""\
@@ -80,42 +106,6 @@ foo [any-i386] binary: another-tag optional-extra
 """, 'overrides')
 
 
-class ParseOverrideTests(TestCase):
-
-    def test_tag_only(self):
-        self.assertEqual(
-            Override(tag='sometag'),
-            parse_override('sometag\n'))
-
-    def test_origin(self):
-        self.assertEqual(
-            Override(tag='sometag', package='mypkg'),
-            parse_override('mypkg: sometag\n'))
-
-    def test_archlist(self):
-        self.assertEqual(
-            Override(tag='sometag', archlist='i386 amd64'),
-            parse_override('[i386 amd64]: sometag\n'))
-
-
-class SerializeOverrideTests(TestCase):
-
-    def test_tag_only(self):
-        self.assertEqual(
-            serialize_override(Override(tag='sometag')),
-            'sometag\n')
-
-    def test_origin(self):
-        self.assertEqual(
-            serialize_override(Override(tag='sometag', package='mypkg')),
-            'mypkg: sometag\n')
-
-    def test_archlist(self):
-        self.assertEqual(
-            serialize_override(Override(tag='sometag', archlist='i386')),
-            '[i386]: sometag\n')
-
-
 class OverrideExistsTests(TestCaseWithTransport):
 
     def test_override_exists(self):
@@ -126,10 +116,11 @@ class OverrideExistsTests(TestCaseWithTransport):
 blah source: patch-file-exists-but info
 """)])
         self.assertEqual([
-            Override(package='blah', archlist=None, type='source',
-                     tag='patch-file-exists-but', info='info')],
+            LintianOverride(
+                package='blah', archlist=None, type='source',
+                tag='patch-file-exists-but', info='info')],
             list(_get_overrides()))
         self.assertTrue(override_exists('patch-file-exists-but', info='info'))
         self.assertFalse(override_exists('patch-file-exists-but', info='no'))
         self.assertTrue(override_exists(
-            'patch-file-exists-but', info='info', package='source'))
+            tag='patch-file-exists-but', info='info', package='blah'))
